@@ -4,6 +4,6 @@ use std::io;
 async fn main() -> io::Result<()> {
     let footer = format!("{} {}", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION"));
 
-    warpy::server::run(".".to_string(), [0, 0, 0, 0], footer, None).await?;
+    warpy::server::run(".".to_string(), [0, 0, 0, 0], footer, None, false).await?;
     Ok(())
 }
